@@ -1,24 +1,20 @@
 package Yukki::Web::Plugin::Viewer;
-$Yukki::Web::Plugin::Viewer::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::Viewer::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Types::Standard qw( HashRef Str );
+BEGIN {
+  $Yukki::Web::Plugin::Viewer::VERSION = '0.111660';
+}
+use 5.12.1;
+use Moose;
 
 extends 'Yukki::Web::Plugin';
 
 use Yukki::Error qw( http_throw );
 
-use namespace::clean;
-
 # ABSTRACT: plugin for custom page viewers
 
 
 has format_helpers => (
     is          => 'ro',
-    isa         => HashRef[Str],
+    isa         => 'HashRef[Str]',
     required    => 1,
     default     => sub { +{
         'show view' => 'show_view_link',
@@ -48,7 +44,7 @@ sub show_view_link {
     my $args = "?view=$view";
        $args = '' if $view eq 'default';
 
-    $ctx->response->add_navigation_item([ qw( page page_bottom ) ] => {
+    $ctx->response->add_navigation_item({
         label => $view_info->{label},
         href  => join('/', 'page/view', $repo, $page)
                 . $args,
@@ -61,18 +57,15 @@ sub show_view_link {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::Viewer - plugin for custom page viewers
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111660
 
 =head1 SYNOPSIS
 
@@ -100,9 +93,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
